#ifndef __OBJECT_ICE
#define __OBJECT_ICE

#include <jast/common/Location.ice>

module jast {
    module common {
        enum ObjectType {
            Bolt, Cube, Slat, Nut, Tower, Windmill, LShape, RailwaySignal, AnyType
        };

        ["java:type:java.util.LinkedList<jast.common.ObjectType>"]
        sequence<ObjectType> ObjectTypeList;

        enum ObjectProp {
            Color, Size
        };

        /** A set of object properties */
        dictionary<ObjectProp,string> ObjectPropMap;

        /**
          A basic object description. This describes an object but does not refer to a specific
          object in the world.
         **/
        // Formerly a class -- make sure the C++ mapping doesn't change
        ["cpp:class"]
        struct ObjectDesc {
            // Only for simple objects
            ObjectType type;
            ObjectPropMap props;
        };

        /**
          A set of object descriptions.
         **/        
        ["java:type:java.util.LinkedList<jast.common.ObjectDesc>"]
        sequence<ObjectDesc> ObjectDescList;

        /** An actual object in the world: it has a description, a world
         * ID, and a location */
        // Formerly a class -- make sure the C++ mapping doesn't change
        ["cpp:class"]
        struct InstantiatedObject {
            string worldId;
            ObjectDesc desc;
            Location loc;
        };

        ["java:type:java.util.LinkedList<jast.common.InstantiatedObject>"]
        sequence<InstantiatedObject> InstantiatedObjectList;
    };
};


#endif // __OBJECT_ICE
